==> ejc-sale-impl-3.0.0-20220605.112218-140-sources.jar: com/ejianc/business/sale/bean/SalesdeliveryEntity.java <==
package com.ejianc.business.sale.bean;

import java.util.Date;
import java.math.*;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 销售发货子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sale_salesdelivery")
public class SalesdeliveryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private Long mid; // 销售单主表id
    @TableField(value="customer_id")
    private Long customerId; // 客户主键
    @TableField(value="customer_name")
    private String customerName; // 客户名称
    @TableField(value="project_id")
    private Long projectId; // 工程主键
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="worksite_id")
    private Long worksiteId; // 工地主键
    @TableField(value="worksite_name")
    private String worksiteName; // 工地名称
    @TableField(value="product_id")
    private Long productId; // 产品主键
    @TableField(value="product_name")
    private String productName; // 产品名称
    @TableField(value="ship_date")
    private Date shipDate; // 发货日期
    @TableField(value="number_plate")
    private String numberPlate; // 车号
    @TableField(value="net_weight")
    private BigDecimal netWeight; // 净重
    @TableField(value="shipping_method")
    private Integer shippingMethod; // 运输方式:0代运1自运
    @TableField(value="freight")
    private BigDecimal freight; // 运费
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="shipment_type")
    private Integer shipmentType; // 发货类型  0-手动发货 1-自动发货
    @TableField(value="confirm_number")
    private BigDecimal confirmNumber; // 确认数
    @TableField(value="receipt_status")
    private Integer receiptStatus; // 回执单状态  0-已勾  1-未勾
    @TableField(value="ship_dates")
    private Date shipDates; // 发货日期年月日
    
    
    

    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }
    public Long getCustomerId() {
        return customerId;
    }

    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }
    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getWorksiteId() {
        return worksiteId;
    }

    public void setWorksiteId(Long worksiteId) {
        this.worksiteId = worksiteId;
    }
    public String getWorksiteName() {
        return worksiteName;
    }

    public void setWorksiteName(String worksiteName) {
        this.worksiteName = worksiteName;
    }
    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public Date getShipDate() {
        return shipDate;
    }

    public void setShipDate(Date shipDate) {
        this.shipDate = shipDate;
    }
    public String getNumberPlate() {
        return numberPlate;
    }

    public void setNumberPlate(String numberPlate) {
        this.numberPlate = numberPlate;
    }
    public BigDecimal getNetWeight() {
        return netWeight;
    }

    public void setNetWeight(BigDecimal netWeight) {
        this.netWeight = netWeight;
    }
    public Integer getShippingMethod() {
        return shippingMethod;
    }

    public void setShippingMethod(Integer shippingMethod) {
        this.shippingMethod = shippingMethod;
    }
    public BigDecimal getFreight() {
        return freight;
    }

    public void setFreight(BigDecimal freight) {
        this.freight = freight;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getShipmentType() {
        return shipmentType;
    }

    public void setShipmentType(Integer shipmentType) {
        this.shipmentType = shipmentType;
    }
    public BigDecimal getConfirmNumber() {
        return confirmNumber;
    }

    public void setConfirmNumber(BigDecimal confirmNumber) {
        this.confirmNumber = confirmNumber;
    }
    public Integer getReceiptStatus() {
        return receiptStatus;
    }

    public void setReceiptStatus(Integer receiptStatus) {
        this.receiptStatus = receiptStatus;
    }
    public Date getShipDates() {
        return shipDates;
    }

    public void setShipDates(Date shipDates) {
        this.shipDates = shipDates;
    }
    
}

==> ejc-sale-impl-3.0.0-20220725.055959-186-sources.jar: com/ejianc/business/sale/bean/SalesdeliveryEntity.java <==
package com.ejianc.business.sale.bean;

import java.util.Date;
import java.math.*;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 销售发货子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sale_salesdelivery")
public class SalesdeliveryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private Long mid; // 销售单主表id
    @TableField(value="customer_id")
    private Long customerId; // 客户主键
    @TableField(value="customer_name")
    private String customerName; // 客户名称
    @TableField(value="project_id")
    private Long projectId; // 工程主键
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="worksite_id")
    private Long worksiteId; // 工地主键
    @TableField(value="worksite_name")
    private String worksiteName; // 工地名称
    @TableField(value="product_id")
    private Long productId; // 产品主键
    @TableField(value="product_name")
    private String productName; // 产品名称
    @TableField(value="ship_date")
    private Date shipDate; // 发货日期
    @TableField(value="number_plate")
    private String numberPlate; // 车号
    @TableField(value="net_weight")
    private BigDecimal netWeight; // 净重
    @TableField(value="shipping_method")
    private Integer shippingMethod; // 运输方式:0代运1自运
    @TableField(value="freight")
    private BigDecimal freight; // 运费
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="shipment_type")
    private Integer shipmentType; // 发货类型  0-手动发货 1-自动发货
    @TableField(value="confirm_number")
    private BigDecimal confirmNumber; // 确认数
    @TableField(value="receipt_status")
    private Integer receiptStatus; // 回执单状态  0-已勾  1-未勾
    @TableField(value="ship_dates")
    private Date shipDates; // 发货日期年月日
    @TableField(value="manualshipment_id")
    private Long manualshipmentId; // 发货单id
    
    
    

    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }
    public Long getCustomerId() {
        return customerId;
    }

    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }
    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getWorksiteId() {
        return worksiteId;
    }

    public void setWorksiteId(Long worksiteId) {
        this.worksiteId = worksiteId;
    }
    public String getWorksiteName() {
        return worksiteName;
    }

    public void setWorksiteName(String worksiteName) {
        this.worksiteName = worksiteName;
    }
    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public Date getShipDate() {
        return shipDate;
    }

    public void setShipDate(Date shipDate) {
        this.shipDate = shipDate;
    }
    public String getNumberPlate() {
        return numberPlate;
    }

    public void setNumberPlate(String numberPlate) {
        this.numberPlate = numberPlate;
    }
    public BigDecimal getNetWeight() {
        return netWeight;
    }

    public void setNetWeight(BigDecimal netWeight) {
        this.netWeight = netWeight;
    }
    public Integer getShippingMethod() {
        return shippingMethod;
    }

    public void setShippingMethod(Integer shippingMethod) {
        this.shippingMethod = shippingMethod;
    }
    public BigDecimal getFreight() {
        return freight;
    }

    public void setFreight(BigDecimal freight) {
        this.freight = freight;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getShipmentType() {
        return shipmentType;
    }

    public void setShipmentType(Integer shipmentType) {
        this.shipmentType = shipmentType;
    }
    public BigDecimal getConfirmNumber() {
        return confirmNumber;
    }

    public void setConfirmNumber(BigDecimal confirmNumber) {
        this.confirmNumber = confirmNumber;
    }
    public Integer getReceiptStatus() {
        return receiptStatus;
    }

    public void setReceiptStatus(Integer receiptStatus) {
        this.receiptStatus = receiptStatus;
    }
    public Date getShipDates() {
        return shipDates;
    }

    public void setShipDates(Date shipDates) {
        this.shipDates = shipDates;
    }

    public Long getManualshipmentId() {
        return manualshipmentId;
    }

    public void setManualshipmentId(Long manualshipmentId) {
        this.manualshipmentId = manualshipmentId;
    }
}
